@@ -108,3 +108,10 @@ PROCESSOR_ARCH_IA_64 = 'Intel Itanium'
 PROCESSOR_ARCH_ARM = 'ARM'
 PROCESSOR_ARCH_MIPS = 'MIPS'
 PROCESSOR_ARCH_OEM = 'OEM-defined'
+
+# Health related constants.
+HEALTH_STATE_ENABLED = 'Enabled'
+HEALTH_STATE_DISABLED = 'Disabled'
+HEALTH_OK = 'OK'
+HEALTH_WARNING = 'Warning'
+HEALTH_CRITICAL = 'Critical'
