@@ -19,8 +19,10 @@ from sushy import exceptions
 from sushy.resources import base
 from sushy.resources import common
 from sushy.resources.system import constants as sys_cons
+from sushy.resources.system import ethernet_interface
 from sushy.resources.system import mappings as sys_maps
 from sushy.resources.system import processor
+from sushy import utils
 
 
 LOG = logging.getLogger(__name__)
@@ -52,7 +54,7 @@ class MemorySummaryField(base.CompositeField):
     This signifies health state of memory along with its dependent resources.
     """
 
-    size_gib = base.Field('TotalSystemMemoryGiB', adapter=int)
+    size_gib = base.Field('TotalSystemMemoryGiB', adapter=utils.int_or_none)
     """The size of memory of the system in GiB.
 
     This signifies the total installed, operating system-accessible memory
@@ -117,6 +119,8 @@ class System(base.ResourceBase):
 
     _actions = ActionsField('Actions', required=True)
 
+    _ethernet_interfaces = None
+
     def __init__(self, connector, identity, redfish_version=None):
         """A class representing a ComputerSystem
 
@@ -240,11 +244,7 @@ class System(base.ResourceBase):
 
     def _get_processor_collection_path(self):
         """Helper function to find the ProcessorCollection path"""
-        processor_col = self.json.get('Processors')
-        if not processor_col:
-            raise exceptions.MissingAttributeError(attribute='Processors',
-                                                   resource=self._path)
-        return processor_col.get('@odata.id')
+        return utils.get_sub_resource_path_by(self, 'Processors')
 
     @property
     def processors(self):
@@ -263,6 +263,18 @@ class System(base.ResourceBase):
     def refresh(self):
         super(System, self).refresh()
         self._processors = None
+        self._ethernet_interfaces = None
+
+    @property
+    def ethernet_interfaces(self):
+        if self._ethernet_interfaces is None:
+            self._ethernet_interfaces = (
+                ethernet_interface.EthernetInterfaceCollection(
+                    self._conn,
+                    utils.get_sub_resource_path_by(self, "EthernetInterfaces"),
+                    redfish_version=self.redfish_version))
+
+        return self._ethernet_interfaces
 
 
 class SystemCollection(base.ResourceCollectionBase):
